#!/bin/bash
#This file has been used to run all the simulation experiments on speedups presented in section 'Analysis speedups' and Table 3 of the main text.
#This file assumes that:
# - StochKit2 has been installed following the instructions in https://github.com/StochSS/StochKit
# - the file has been placed in the main folder of StochKit, next to the folders 'bin' and 'models'.
# - the folder erode2stochkit created by ERODE with all the models encoded in StochKit format has been placed within the folder 'models' 
#run with ./runSim.sh &> output.txt


#SSA Gillespie
#./bin/ssa_direct_serial

#Next reaction method Gibson & Bruck
#./bin/ssa_nrm_serial

#Logarithmic Direct Method Li & Petzold
#ssa_ldm_serial

#Constant-time Slepoy et al
#ssa_constant_serial

repeats=5
for model in "NIHMS80246-S6SE.xml" "NIHMS80246-S6.xml" "NIHMS80246-S4SE.xml" "NIHMS80246-S4.xml" "fceri_jiSE.xml" "fceri_ji.xml" "fceri_lyn_745.xml" "fceri_lyn_745SE.xml" "fceri_fyn.xml" "fceri_fynSE.xml" "sx_fceri_ji_sitell.xml" "sx_fceri_ji_sitellSE.xml" "Nag2009SE.xml" "fceri_gamma2_asymSE.xml" "fceri_fyn_trimerSE.xml" "Nag2009.xml" "fceri_gamma2_asym.xml" "fceri_fyn_trimer.xml"
do
	for method in "ssa_direct_serial" "ssa_nrm_serial" "ssa_ldm_serial" "ssa_constant_serial"
	do
		th="3840"
		if [[ $model == "NIHMS"* ]]
			then th="40"
		fi
		if [[ $model == "sx_"* ]]
			then th="3600"
		fi
		if [[ $model == "BIOMD"* ]]
			then th="100" 
		fi
		if [[ $model == "Nag2009"* ]]
			then th="200" 
		fi	
		date +"%T"
		command="./bin/$method -m ./models/erode2stochkit/$model -t $th -r $repeats -f"
		echo $command
		time $command
		printf "\n\n\n\n"
	done
done